<?php

namespace Boilerplate\Boilerplate\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Form;
use Boilerplate\Boilerplate\Http\Requests\BoilerplateI18nAdminRequest;
use Boilerplate\Boilerplate\Interfaces\BoilerplateI18nRepositoryInterface;
use Boilerplate\Boilerplate\Models\BoilerplateI18n;

/**
 * Admin controller class.
 */
class BoilerplateI18nAdminController extends AdminController
{
    /**
     * Initialize boilerplate_i18n controller.
     *
     * @param type BoilerplateI18nRepositoryInterface $boilerplate_i18n
     *
     * @return type
     */
    public function __construct(BoilerplateI18nRepositoryInterface $boilerplate_i18n)
    {
        parent::__construct();
        $this->repository = $boilerplate_i18n;
    }

    /**
     * Display a list of boilerplate_i18n.
     *
     * @return Response
     */
    public function index(BoilerplateI18nAdminRequest $request)
    {
        $boilerplate_i18ns  = $this->repository->setPresenter('\\Boilerplate\\Boilerplate\\Repositories\\Presenter\\BoilerplateI18nListPresenter')
                                            ->scopeQuery(function($query){
                                                return $query->orderBy('id','DESC');
                                            })->paginate();
        $this   ->theme->prependTitle(trans('boilerplate::boilerplate_i18n.names').' :: ');
        $view   = $this->theme->of('boilerplate::admin.boilerplate_i18n.index')->render();

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
        $this->responseData = $boilerplate_i18ns['data'];
        $this->responseMeta = $boilerplate_i18ns['meta'];
        $this->responseView = $view;
        $this->responseRedirect = '';
        return $this->respond($request);
    }

    /**
     * Display boilerplate_i18n.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(BoilerplateI18nAdminRequest $request, BoilerplateI18n $boilerplate_i18n)
    {
        if (!$boilerplate_i18n->exists) {
            $this->responseCode = 404;
            $this->responseMessage = trans('messages.success.notfound', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
            $this->responseView = view('boilerplate::admin.boilerplate_i18n.new');
            return $this -> respond($request);
        }

        Form::populate($boilerplate_i18n);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
        $this->responseData = $boilerplate_i18n;
        $this->responseView = view('boilerplate::admin.boilerplate_i18n.show', compact('boilerplate_i18n'));
        return $this -> respond($request);
    }

    /**
     * Show the form for creating a new boilerplate_i18n.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BoilerplateI18nAdminRequest $request)
    {

        $boilerplate_i18n = $this->repository->newInstance([]);

        Form::populate($boilerplate_i18n);

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
        $this->responseData = $boilerplate_i18n;
        $this->responseView = view('boilerplate::admin.boilerplate_i18n.create', compact('boilerplate_i18n'));
        return $this -> respond($request);

    }

    /**
     * Create new boilerplate_i18n.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BoilerplateI18nAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $boilerplate_i18n = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
            $this->responseData = $boilerplate_i18n;
            $this->responseMeta = '';
            $this->responseRedirect = trans_url('/admin/boilerplate/boilerplate_i18n/'.$boilerplate_i18n->getRouteKey());
            $this->responseView = view('boilerplate::admin.boilerplate_i18n.create', compact('boilerplate_i18n'));

            return $this -> respond($request);

        } catch (Exception $e) {
            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            return $this -> respond($request);
        }
    }

    /**
     * Show boilerplate_i18n for editing.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(BoilerplateI18nAdminRequest $request, BoilerplateI18n $boilerplate_i18n)
    {
        Form::populate($boilerplate_i18n);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
        $this->responseData = $boilerplate_i18n;
        $this->responseView = view('boilerplate::admin.boilerplate_i18n.edit', compact('boilerplate_i18n'));

        return $this -> respond($request);
    }

    /**
     * Update the boilerplate_i18n.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(BoilerplateI18nAdminRequest $request, BoilerplateI18n $boilerplate_i18n)
    {
        try {

            $attributes = $request->all();

            $boilerplate_i18n->update($attributes);

            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
            $this->responseData = $boilerplate_i18n;
            $this->responseRedirect = trans_url('/admin/boilerplate/boilerplate_i18n/'.$boilerplate_i18n->getRouteKey());

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/boilerplate/boilerplate_i18n/'.$boilerplate_i18n->getRouteKey());

            return $this -> respond($request);
        }
    }

    /**
     * Remove the boilerplate_i18n.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BoilerplateI18nAdminRequest $request, BoilerplateI18n $boilerplate_i18n)
    {

        try {

            $t = $boilerplate_i18n->delete();

            $this->responseCode = 202;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
            $this->responseRedirect = trans_url('/admin/boilerplate/boilerplate_i18n/0');

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/boilerplate/boilerplate_i18n/'.$boilerplate_i18n->getRouteKey());

            return $this -> respond($request);

        }
    }
}
