<?php

namespace Boilerplate\Boilerplate\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Form;
use Boilerplate\Boilerplate\Http\Requests\BoilerplateI18nUserRequest;
use Boilerplate\Boilerplate\Interfaces\BoilerplateI18nRepositoryInterface;
use Boilerplate\Boilerplate\Models\BoilerplateI18n;

class BoilerplateI18nUserController extends UserController
{
    /**
     * Initialize boilerplate_i18n controller.
     *
     * @param type BoilerplateI18nRepositoryInterface $boilerplate_i18n
     *
     * @return type
     */
    public function __construct(BoilerplateI18nRepositoryInterface $boilerplate_i18n)
    {
        $this->repository = $boilerplate_i18n;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(BoilerplateI18nUserRequest $request)
    {
        $this->repository->pushCriteria(new \Lavalite\Boilerplate\Repositories\Criteria\BoilerplateI18nUserCriteria());
        $boilerplate_i18ns = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('boilerplate::boilerplate_i18n.names').' :: ');

        return $this->theme->of('boilerplate::user.boilerplate_i18n.index', compact('boilerplate_i18ns'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param BoilerplateI18n $boilerplate_i18n
     *
     * @return Response
     */
    public function show(BoilerplateI18nUserRequest $request, BoilerplateI18n $boilerplate_i18n)
    {
        Form::populate($boilerplate_i18n);

        return $this->theme->of('boilerplate::user.boilerplate_i18n.show', compact('boilerplate_i18n'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BoilerplateI18nUserRequest $request)
    {

        $boilerplate_i18n = $this->repository->newInstance([]);
        Form::populate($boilerplate_i18n);

        return $this->theme->of('boilerplate::user.boilerplate_i18n.create', compact('boilerplate_i18n'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BoilerplateI18nUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $boilerplate_i18n = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
            $this->responseRedirect = trans_url('/user/boilerplate/boilerplate_i18n');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param BoilerplateI18n $boilerplate_i18n
     *
     * @return Response
     */
    public function edit(BoilerplateI18nUserRequest $request, BoilerplateI18n $boilerplate_i18n)
    {

        Form::populate($boilerplate_i18n);

        return $this->theme->of('boilerplate::user.boilerplate_i18n.edit', compact('boilerplate_i18n'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param BoilerplateI18n $boilerplate_i18n
     *
     * @return Response
     */
    public function update(BoilerplateI18nUserRequest $request, BoilerplateI18n $boilerplate_i18n)
    {
        try {
            $this->repository->update($request->all(), $boilerplate_i18n->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
            $this->responseRedirect = trans_url('/user/boilerplate/boilerplate_i18n');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BoilerplateI18nUserRequest $request, BoilerplateI18n $boilerplate_i18n)
    {
        try {
            $this->repository->delete($boilerplate_i18n->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('boilerplate::boilerplate_i18n.name')]);
            $this->responseRedirect = trans_url('/user/boilerplate/boilerplate_i18n');
            return $this -> respond($request);
        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
