<?php

namespace Boilerplate\Boilerplate\Http\Requests;

use App\Http\Requests\Request as FormRequest;
use Illuminate\Http\Request;
use Gate;

class BoilerplateUserRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(Request $request)
    {
        $boilerplate = $this->route('boilerplate');
        // Determine if the user is authorized to access boilerplate module,
        if (is_null($boilerplate)) {
            return $request->user()->canDo('boilerplate.boilerplate.view');
        }

        // Determine if the user is authorized to create an entry,
        if ($request->isMethod('POST') || $request->is('*/create')) {
            return Gate::allows('create', $boilerplate);
        }

        // Determine if the user is authorized to update an entry,
        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            return Gate::allows('update', $boilerplate);
        }

        // Determine if the user is authorized to delete an entry,
        if ($request->isMethod('DELETE')) {
            return Gate::allows('delete', $boilerplate);
        }

        // Determine if the user is authorized to view the module.
        return Gate::allows('view', $boilerplate);

    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(Request $request)
    {
        // validation rule for create request.
        if ($request->isMethod('POST')) {
            return [
                'title'               => 'required',
            ];
        }
        // Validation rule for update request.
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            return [
                'title'               => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
