<?php

namespace Boilerplate\Boilerplate\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Boilerplate\Boilerplate\Models\BoilerplateI18n;

class BoilerplateI18nPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the boilerplate_i18n.
     *
     * @param User $user
     * @param BoilerplateI18n $boilerplate_i18n
     *
     * @return bool
     */
    public function view(User $user, BoilerplateI18n $boilerplate_i18n)
    {
        if ($user->canDo('boilerplate.boilerplate_i18n.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $boilerplate_i18n->user_id;
    }

    /**
     * Determine if the given user can create a boilerplate_i18n.
     *
     * @param User $user
     * @param BoilerplateI18n $boilerplate_i18n
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('boilerplate.boilerplate_i18n.create');
    }

    /**
     * Determine if the given user can update the given boilerplate_i18n.
     *
     * @param User $user
     * @param BoilerplateI18n $boilerplate_i18n
     *
     * @return bool
     */
    public function update(User $user, BoilerplateI18n $boilerplate_i18n)
    {
        if ($user->canDo('boilerplate.boilerplate_i18n.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $boilerplate_i18n->user_id;
    }

    /**
     * Determine if the given user can delete the given boilerplate_i18n.
     *
     * @param User $user
     * @param BoilerplateI18n $boilerplate_i18n
     *
     * @return bool
     */
    public function delete(User $user, BoilerplateI18n $boilerplate_i18n)
    {
        if ($user->canDo('boilerplate.boilerplate_i18n.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $boilerplate_i18n->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
