<?php

namespace Boilerplate\Boilerplate\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Boilerplate\Boilerplate\Models\Boilerplate;

class BoilerplatePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the boilerplate.
     *
     * @param User $user
     * @param Boilerplate $boilerplate
     *
     * @return bool
     */
    public function view(User $user, Boilerplate $boilerplate)
    {
        if ($user->canDo('boilerplate.boilerplate.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $boilerplate->user_id;
    }

    /**
     * Determine if the given user can create a boilerplate.
     *
     * @param User $user
     * @param Boilerplate $boilerplate
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('boilerplate.boilerplate.create');
    }

    /**
     * Determine if the given user can update the given boilerplate.
     *
     * @param User $user
     * @param Boilerplate $boilerplate
     *
     * @return bool
     */
    public function update(User $user, Boilerplate $boilerplate)
    {
        if ($user->canDo('boilerplate.boilerplate.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $boilerplate->user_id;
    }

    /**
     * Determine if the given user can delete the given boilerplate.
     *
     * @param User $user
     * @param Boilerplate $boilerplate
     *
     * @return bool
     */
    public function delete(User $user, Boilerplate $boilerplate)
    {
        if ($user->canDo('boilerplate.boilerplate.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $boilerplate->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
