<?php

namespace Boilerplate\Boilerplate\Providers;

use Illuminate\Support\ServiceProvider;

class BoilerplateServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'boilerplate');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'boilerplate');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('boilerplate', function ($app) {
            return $this->app->make('Boilerplate\Boilerplate\Boilerplate');
        });

// Bind Boilerplate to repository
        $this->app->bind(
            \Boilerplate\Boilerplate\Interfaces\BoilerplateRepositoryInterface::class,
            \Boilerplate\Boilerplate\Repositories\Eloquent\BoilerplateRepository::class
        );
        // Bind BoilerplateI18n to repository
        $this->app->bind(
            \Boilerplate\Boilerplate\Interfaces\BoilerplateI18nRepositoryInterface::class,
            \Boilerplate\Boilerplate\Repositories\Eloquent\BoilerplateI18nRepository::class
        );

        $this->app->register(\Boilerplate\Boilerplate\Providers\AuthServiceProvider::class);
        $this->app->register(\Boilerplate\Boilerplate\Providers\EventServiceProvider::class);
        $this->app->register(\Boilerplate\Boilerplate\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['boilerplate'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/boilerplate.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__ . '/../../../../resources/views/public'  => base_path('resources/views/vendor/boilerplate/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views/admin' => base_path('resources/views/vendor/boilerplate/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/boilerplate')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
